# Generated by Django 3.2.13 on 2022-04-12 13:47

import os

from django.conf import settings
from django.db import migrations

from castellum.studies.models import consent_upload_to
from castellum.studies.models import geofilter_upload_to
import castellum.studies.models
import castellum.utils.fields
import castellum.utils.forms


def move_file(_old, _new):
    old = settings.MEDIA_ROOT / _old
    new = settings.MEDIA_ROOT / _new

    try:
        new.parent.mkdir(parents=True, exist_ok=True)
        old.rename(new)
    except FileNotFoundError:
        pass


def migrate_data(apps, schema_editor):
    Study = apps.get_model('studies', 'Study')

    for study in Study.objects.exclude(consent=None):
        old = study.consent.name
        new = consent_upload_to(study, os.path.basename(old))
        if old and old != new:
            move_file(old, new)
            study.consent.name = new
            study.save()

    for study in Study.objects.exclude(geo_filter=None):
        old = study.geo_filter.name
        new = geofilter_upload_to(study, os.path.basename(old))
        if old and old != new:
            move_file(old, new)
            study.geo_filter.name = new
            study.save()


class Migration(migrations.Migration):

    dependencies = [
        ('studies', '0046_rename_study_is_onetime_invitation'),
    ]

    operations = [
        migrations.AlterField(
            model_name='study',
            name='consent',
            field=castellum.utils.fields.RestrictedFileField(
                blank=True,
                help_text='A blueprint of the study consent. This file can be obtained (and printed) later by recruiters or conductors.',
                upload_to=castellum.studies.models.consent_upload_to,
                verbose_name='Study consent',
            ),
        ),
        migrations.AlterField(
            model_name='study',
            name='geo_filter',
            field=castellum.utils.fields.RestrictedFileField(
                blank=True,
                help_text='A GeoJSON file that contains only a single (multi)polygon. Only subjects who live inside this polygon will be considered for this study.',
                upload_to=castellum.studies.models.geofilter_upload_to,
                validators=[
                    castellum.utils.forms.JsonFileValidator(
                        {
                            '$defs': {
                                'Feature': {
                                    'properties': {
                                        'geometry': {
                                            'oneOf': [
                                                {'$ref': '#/$defs/Polygon'},
                                                {'$ref': '#/$defs/MultiPolygon'},
                                            ]
                                        },
                                        'properties': {
                                            'oneOf': [
                                                {'type': 'null'},
                                                {'type': 'object'},
                                            ]
                                        },
                                        'type': {'enum': ['Feature'], 'type': 'string'},
                                    },
                                    'required': ['type', 'properties', 'geometry'],
                                    'type': 'object',
                                },
                                'MultiPolygon': {
                                    'properties': {
                                        'coordinates': {
                                            'items': {'$ref': '#/$defs/MultiPolygon'},
                                            'type': 'array',
                                        },
                                        'type': {
                                            'enum': ['MultiPolygon'],
                                            'type': 'string',
                                        },
                                    },
                                    'required': ['type', 'coordinates'],
                                    'type': 'object',
                                },
                                'Polygon': {
                                    'properties': {
                                        'coordinates': {
                                            '$ref': '#/$defs/PolygonCoordinates'
                                        },
                                        'type': {'enum': ['Polygon'], 'type': 'string'},
                                    },
                                    'required': ['type', 'coordinates'],
                                    'type': 'object',
                                },
                                'PolygonCoordinates': {
                                    'items': {
                                        'items': {
                                            'items': {'type': 'number'},
                                            'minItems': 2,
                                            'type': 'array',
                                        },
                                        'minItems': 4,
                                        'type': 'array',
                                    },
                                    'type': 'array',
                                },
                            },
                            '$schema': 'http://json-schema.org/draft-07/schema#',
                        },
                        '#/$defs/Feature',
                    )
                ],
                verbose_name='Geo filter file',
            ),
        ),
        migrations.RunPython(migrate_data),
    ]
