# Generated by Django 3.2.8 on 2021-10-20 15:15

from django.db import migrations, models


def factory(app, model_name):
    def migrate_data(apps, schema_editor):
        Model = apps.get_model(app, model_name)
        for obj in Model.objects.all().select_related('subject'):
            obj.subject_uuid = obj.subject.uuid
            obj.save()

    return migrate_data


def factory_m2m(app, model_name, rel_name):
    def migrate_data(apps, schema_editor):
        Subject = apps.get_model('subjects', 'Subject')
        Model = apps.get_model(app, model_name)
        for subject in Subject.objects.all():
            qs = getattr(subject, rel_name)
            for obj in qs.all():
                Model.objects.create(subject_uuid=subject.uuid, obj=obj)

    return migrate_data


class Migration(migrations.Migration):

    dependencies = [
        ('studies', '0041_alter_study_consent'),
        ('subjects', '0029_subjectcreationrequest_data_is_deleted'),
    ]

    operations = [
        migrations.AddField(
            model_name='consent',
            name='subject_uuid',
            field=models.UUIDField(null=True),
        ),
        migrations.RunPython(factory('subjects', 'Consent')),
        migrations.RemoveField(
            model_name='consent',
            name='subject',
        ),
        migrations.AddField(
            model_name='exportanswer',
            name='subject_uuid',
            field=models.UUIDField(null=True),
        ),
        migrations.RunPython(factory('subjects', 'ExportAnswer')),
        migrations.RemoveField(
            model_name='exportanswer',
            name='subject',
        ),
        migrations.AddField(
            model_name='subjectnote',
            name='subject_uuid',
            field=models.UUIDField(null=True),
        ),
        migrations.RunPython(factory('subjects', 'SubjectNote')),
        migrations.RemoveField(
            model_name='subjectnote',
            name='subject',
        ),
        migrations.CreateModel(
            name='StudyTypeDisinterest',
            fields=[
                (
                    'id',
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name='ID',
                    ),
                ),
                ('subject_uuid', models.UUIDField()),
                (
                    'obj',
                    models.ForeignKey(
                        on_delete=models.deletion.CASCADE,
                        related_name='+',
                        to='studies.studytype',
                    ),
                ),
            ],
        ),
        migrations.RunPython(
            factory_m2m('subjects', 'StudyTypeDisinterest', 'study_type_disinterest')
        ),
        migrations.RemoveField(
            model_name='subject',
            name='study_type_disinterest',
        ),
        migrations.CreateModel(
            name='AdditionalSuitabilityDocument',
            fields=[
                (
                    'id',
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name='ID',
                    ),
                ),
                ('subject_uuid', models.UUIDField()),
                (
                    'obj',
                    models.ForeignKey(
                        on_delete=models.deletion.CASCADE,
                        related_name='+',
                        to='studies.studytype',
                    ),
                ),
            ],
        ),
        migrations.RunPython(
            factory_m2m(
                'subjects',
                'AdditionalSuitabilityDocument',
                'additional_suitability_document',
            )
        ),
        migrations.RemoveField(
            model_name='subject',
            name='additional_suitability_document',
        ),
    ]
